@@ -3,10 +3,10 @@
 #include "type.h"
 
 
-int initialize(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo);
-int polarityChk(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo);
-int ChkConvergence(PROBLEMINFOptr probleminfo, ENTITYINFOptr entityinfo);
-int dgesvd_pcal1 (char jobu, char jobvt, int m, int n, double *A, int lda, double *S, double *VT, int ldu, double *Umat, int ldvt, double *work, int lwork); /* SVD */
+static int initialize(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo);
+static int polarityChk(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo);
+static int ChkConvergence(PROBLEMINFOptr probleminfo, ENTITYINFOptr entityinfo);
+static int dgesvd_pcal1 (char jobu, char jobvt, int m, int n, double *A, int lda, double *S, double *VT, int ldu, double *Umat, int ldvt, double *work, int lwork); /* SVD */
 
 int solvePcaL1(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo)
 {
@@ -48,16 +48,18 @@ int solvePcaL1(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo)
    }
     
    probleminfo->convergent = 0;
-   while (probleminfo->convergent == 0) {
-     status = polarityChk(entityinfo, probleminfo);
-     if(status) {
-       REprintf("Polarity Check failed \n");
-       return 1;
-     }
-     status = ChkConvergence(probleminfo, entityinfo);
-     if(status) {
-       REprintf("Convergence Check failed\n");
-       return 1;
+   if (k < (numattributes_m - 1)) {
+     while (probleminfo->convergent == 0) {
+         status = polarityChk(entityinfo, probleminfo);
+         if(status) {
+           REprintf("Polarity Check failed \n");
+           return 1;
+         }
+         status = ChkConvergence(probleminfo, entityinfo);
+         if(status) {
+           REprintf("Convergence Check failed\n");
+           return 1;
+         }
      }
    }
    for (j = 0; j < numattributes_m ; ++j) {
@@ -66,7 +68,7 @@ int solvePcaL1(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo)
  }
  return 0;
 } /* end solvePcaL1 */
-int initialize(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo) {
+static int initialize(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo) {
   int numentities_n   = entityinfo->numentities_n;
   int numattributes_m = entityinfo->numattributes_m;
   double *points_XT    = entityinfo->points_XT;
@@ -94,7 +96,7 @@ int initialize(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo) {
         points_XT_temp[numattributes_m*i+j] = points_XT[numattributes_m*i+j];
       }
     }
-    
+   
     status = dgesvd_pcal1 ('O', 'N', numattributes_m, numentities_n, points_XT, numattributes_m, S, NULL, 1, NULL, 1, work, lwork);  /* the pointer to points_XT gets destroyed here */
     if (status) {
       REprintf("dgesvd failed\n");
@@ -135,7 +137,7 @@ int initialize(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo) {
   else if (initMethod == 2) { /* random vector */
     xSum = 0.0;
     for (j = 0; j < numattributes_m; ++j) {
-      probleminfo->wT[j]= unif_rand();
+      probleminfo->wT[j]= unif_rand() - 0.5;
       xSum += probleminfo->wT[j]*probleminfo->wT[j];
     }
     normalizer = sqrt(xSum);
@@ -147,7 +149,7 @@ int initialize(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo) {
   } 
   return 0;
 }
-int polarityChk(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo) {
+static int polarityChk(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo) {
   double *polarity = probleminfo->polarity;
   int i         = probleminfo->i;
   int j         = probleminfo->j;
@@ -199,7 +201,7 @@ int polarityChk(ENTITYINFOptr entityinfo, PROBLEMINFOptr probleminfo) {
   return 0;
 }
 
-int ChkConvergence(PROBLEMINFOptr probleminfo, ENTITYINFOptr entityinfo) {
+static int ChkConvergence(PROBLEMINFOptr probleminfo, ENTITYINFOptr entityinfo) {
   double *wTOld = probleminfo->wTOld;
   int j = probleminfo->j;
   int dotConv = probleminfo->dotConv;
@@ -223,7 +225,8 @@ int ChkConvergence(PROBLEMINFOptr probleminfo, ENTITYINFOptr entityinfo) {
   if (dotConv == 1) {/*if wT(Xi)=0, then add a small non-zero random vector and do Polarity Check again*/
     probleminfo->convergent = 0;
     for(j = 0; j < numattributes_m; ++j){
-      probleminfo->wT[j] = probleminfo->wT[j] + unif_rand()/100.0;
+      probleminfo->wT[j] = probleminfo->wT[j] + (unif_rand() - 0.5)/100.0;
+      REprintf("%f\n", probleminfo->wT[j]);
       wTSum = wTSum + probleminfo->wT[j] * probleminfo->wT[j];
     }
     Normalizer = sqrt (wTSum);
@@ -236,7 +239,7 @@ int ChkConvergence(PROBLEMINFOptr probleminfo, ENTITYINFOptr entityinfo) {
   return 0;
 }
 
-int dgesvd_pcal1 (char jobu, char jobvt, int m, int n, double *A, int lda, double *S, double *VT, int ldu, double *Umat, int ldvt, double *work, int lwork) { /* SVD */
+static int dgesvd_pcal1 (char jobu, char jobvt, int m, int n, double *A, int lda, double *S, double *VT, int ldu, double *Umat, int ldvt, double *work, int lwork) { /* SVD */
   extern void dgesvd_(const char *jobup, const char *jobvtp, const int *mp, const int *np, double *A, int *ldap, double *S, double *U, const int *ldup, double *Umat, int *ldvtp, double *work, int *lworkp, int *infop);
  
   int info;
